@@ -56,7 +56,7 @@ class utilities:
             URL = "https://api.telegram.org/bot{}/".format(token)
             url = URL + \
                 "sendMessage?text={}&chat_id={}".format(message, receipt_id)
-            return get_url(url)
+            return self.get_url(url)
         except:
             print("Error occured in sending telegram notification")
 
@@ -99,13 +99,13 @@ class utilities:
             return len(checkOrderBook)
         return 0
 
-    def check_open_short_count(orderBook,option_type=None):
+    def check_open_short_count(self, orderBook,option_type=None):
         if option_type is not None:
             checkOrderBook = orderBook.loc[(orderBook['OT'] == option_type) & (orderBook['signal'] == "Short")\
-                & (orderBook['status'] == "complete") & (orderBook['exit_time'].isnull()) ]
+                & (orderBook['status'] == "TRAD") & (orderBook['exit_time'].isnull()) ]
         else:
             checkOrderBook = orderBook.loc[(orderBook['signal'] == "Short") & (orderBook['exit_time'].isnull()) \
-                & (orderBook['status'] == "complete")]
+                & (orderBook['status'] == "TRAD")]
     
         if len(checkOrderBook) > 0:
             return len(checkOrderBook)
